#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-B5GunvyGHm4JytUF8yzg7c
key:                  glirc-2.41-B5GunvyGHm4JytUF8yzg7c
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  adfe1887712bd0cf5c2afc76242233ae
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-B5GunvyGHm4JytUF8yzg7c
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.10-GkJXz0tt9P7F1l9NnCOJf0
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    bytestring-0.11.5.3 config-schema-1.3.0.0-GfzyKBmk1nLIompcx9dwjv
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-64ya6ZpI2lI28VW59Vphtf directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-IPqfEFGY8zS5f5J8nSZGaF
    githash-0.1.7.0-Fg8yc7ROXwtL5yKInFIZ
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hookup-0.8-55GtozayyufD6bI1D3FC3A
    irc-core-2.13-4HhCMzKgET66nXX4xLLfeB
    kan-extensions-5.2.8-CQDAZ8yvs8m2j4Z3QBWQbY
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    psqueues-0.2.8.3-KSZI3Y3ciCjBWgyeE5vyS2
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    regex-tdfa-1.3.2.5-7A9AvRIGkk4HgHOwz4zjio
    semigroupoids-6.0.2-8PUPbvD5alAD9T2ne6W73U
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-HAkQYV8rsLmKAXrwFWyt2n
    unix-2.8.4.0 unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    vty-6.2-BOzgwO86iul8VnrLQQM2PI

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

